# Copyright (C) 2013 Linaro
#
# Author: James Tunnicliffe <james.tunnicliffe@linaro.org>
#
# This file is part of Linaro CI CLI.
#
# Linaro CI CLI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linaro CI CLI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Linaro Image Tools.  If not, see <http://www.gnu.org/licenses/>.

import requests
from base_command import BaseCommandNeedsAuth, CommandFailed
import argparse
import defaults
import simplejson
import re

"""
Defines the lci add command
"""

class Command(BaseCommandNeedsAuth):
    def run(self, args):
        data = simplejson.dumps(self._args_to_params(args))
        parameters = {}
        print "Add task with params %s" % parameters

        print data
        r = self.post("jobs", data, parameters)

        # TODO: server side needs a unique job name.
        # This comes out of the job config, so finding it will be delayed
        # Need to use notification API to report problems to user.
        if r.status_code != requests.codes.created:
            raise CommandFailed(self.name, parameters, r)

    def _args_to_params(self, parameters):
        # lci add <VCS URL> [--file-name file_name] [--class-name class_name]
        # [--run]
        parser = argparse.ArgumentParser(description='Linaro CI: Add task.',
                                         prog=self.program_name)
        parser.add_argument('vcs_url', type=str,
            help='URL to check out test configuration from.')
        parser.add_argument('--file-name', type=str,
            default=defaults.FILE_NAME,
            help='Name of the configuration file.'
                 ' Default is %s' % defaults.FILE_NAME)
        parser.add_argument('--class-name', type=str,
            default=defaults.CLASS_NAME,
            help='Name of the job class in the configuration file. '
                 'Default is %s' % defaults.CLASS_NAME)
        parser.add_argument('--run', action='store_true',
            help='Enqueue job immediately')
        parser.add_argument('--name', type=str)

        args = parser.parse_args(parameters)
        return vars(args)
