# Copyright (C) 2013 Linaro
#
# Author: James Tunnicliffe <james.tunnicliffe@linaro.org>
#
# This file is part of Linaro CI CLI.
#
# Linaro CI CLI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linaro CI CLI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Linaro Image Tools.  If not, see <http://www.gnu.org/licenses/>.

import requests
from base_command import BaseCommandNeedsAuth, CommandFailed
import argparse

"""
Defines the lci get command
"""

class Command(BaseCommandNeedsAuth):
    def run(self, args):
        parameters = self._args_to_params(args)

        print "Get output of task with params %s" % parameters

        r = self.get("get", parameters)

        if r.status_code != requests.codes.ok:
            raise CommandFailed(self.name, parameters, r)

    def _args_to_params(self, parameters):
        # lci get <job ID> [--console]
        parser = argparse.ArgumentParser(
            description='Linaro CI: get task output.',
            prog=self.program_name,)
        parser.add_argument('job_id', type=str, help='Job ID.')
        parser.add_argument('--console', action='store_true',
                            help='Enqueue job immediately')

        args = parser.parse_args(parameters)
        return vars(args)
