# Copyright (C) 2013 Linaro
#
# Author: James Tunnicliffe <james.tunnicliffe@linaro.org>
#
# This file is part of Linaro CI CLI.
#
# Linaro CI CLI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linaro CI CLI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Linaro Image Tools.  If not, see <http://www.gnu.org/licenses/>.

import re
import requests
from urlparse import urljoin
from commands.base_command import BaseCommand
from commands.defaults import CI_SERVER

class Command(BaseCommand):
    def run(self, parameters):
        if(not('username' in self.settings and
               'api_key' in self.settings) or
           not self._test_login()):

            print "Before using the Linaro CI command line tool we need some "\
                "authentication information. This is your launchpad user ID "\
                "and an API key from the web UI. To obtain this information, "\
                "please visit " + urljoin(CI_SERVER, "/api_key")

            self._login()

    def _test_login(self):
        r = self.get("login_test")

        return r.status_code == requests.codes.ok

    def _login(self):
        while True:
            username = raw_input('User ID: ')
            api_key = raw_input('API Key: ')

            if(self._validate_input(username) and
               self._validate_input(api_key)):

                self.settings["username"] = self._validate_input(username)
                self.settings["api_key"] = self._validate_input(api_key)

                if self._test_login():
                    break

            print "There was a problem with those details. Please try "\
                  "again."

    def _validate_input(self, input):
        no_spaces = re.search("^\s*(\S+)\s*$", input)
        if no_spaces:
            input = no_spaces.group(1)
        else:
            return None

        return input
