# Copyright (C) 2013 Linaro
#
# Author: James Tunnicliffe <james.tunnicliffe@linaro.org>
#
# This file is part of Linaro CI CLI.
#
# Linaro CI CLI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linaro CI CLI is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Linaro Image Tools.  If not, see <http://www.gnu.org/licenses/>.

import requests
from base_command import BaseCommandNeedsAuth, CommandFailed
import argparse
import sys, os

"""
Defines the lci status command
"""

class Command(BaseCommandNeedsAuth):
    def run(self, args):
        parameters = self._args_to_params(args)
        r = self.get("loops", parameters)

        if r.status_code != requests.codes.ok:
            raise CommandFailed(self.name, parameters, r)

        print "Status of %s" % parameters
        print r.json()

    def _args_to_params(self, parameters):
        # lci status <job ID> [--group] %s [--user] %s [--job-name] %s
        parser = argparse.ArgumentParser(
            prog=self.program_name,
            description='Linaro CI: get task output.')
        parser.add_argument('--job-id', type=str, help='Job ID.')
        parser.add_argument('--user', type=str, help='User owning job.')
        parser.add_argument('--group', type=str, help='Group owning job.')
        parser.add_argument('--job-name', type=str, help='Job name.')
        parser.add_argument('--mine', action='store_true',
                            help='Jobs belonging to me')
        parser.add_argument('--my-groups', action='store_true',
                            help='Jobs belonging to my group(s)')

        args = parser.parse_args(parameters)

        # TODO: Translate "mine" into a user
        # TODO: Translate "my-groups" into a group list
        # TODO: Work out if supporting a list of goups is sane!

        return vars(args)
